Learn R Programming

hwriter (version 1.3.2)

hwriter-package: HTML writer

Description

hwriter is an easy-to-use package able to format and output R objects in HTML format. It supports advanced formatting, tables, CSS styling, Javascript, images and provides a convenient mapping between R tables and HTML tables. hwriter generates XHTML 1.0 transitional HTML code.

See Examples and hwrite for more details.

The project page is http://www.ebi.ac.uk/~gpau/hwriter.

Arguments

Package content

hwriter provides the following functions (but most of the job is carried out by hwrite):

  • hwrite outputs an R object in HTML format.

  • hwriteImage writes an image.

  • openPage, closePage handles HTML page/document creation.

  • hmakeTag is a low-level HTML tag formatting function.

See Also

hwrite, hwriteImage, openPage, closePage, hmakeTag.

Examples

Run this code
# NOT RUN {
 hwriter:::showExample()
# }

Run the code above in your browser using DataLab